@@ -1,5 +1,5 @@
 package Beam::Minion::Command::worker;
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 # ABSTRACT: Command to run a Beam::Minion worker
 
 #pod =head1 SYNOPSIS
@@ -52,11 +52,14 @@ use Beam::Runner::Util qw( find_container_path );
 use Beam::Minion::Util qw( minion );
 use Scalar::Util qw( weaken );
 use Mojolicious;
+use Mojo::Log;
 use Minion::Command::minion::worker;
 
 sub run {
     my ( $class, $container ) = @_;
-    my $app = Mojolicious->new;
+    my $app = Mojolicious->new(
+        log => Mojo::Log->new, # Log to STDERR
+    );
 
     push @{$app->commands->namespaces}, 'Minion::Command';
 
@@ -93,7 +96,7 @@ Beam::Minion::Command::worker - Command to run a Beam::Minion worker
 
 =head1 VERSION
 
-version 0.005
+version 0.006
 
 =head1 SYNOPSIS
 
